@@ -25,3 +25,9 @@ void AboutDlg::on_licenseButton_clicked()
     LicenseDlg *license = new LicenseDlg(this);
     license->exec();
 }
+
+void AboutDlg::on_webButton_clicked()
+{
+    QUrl webUrl("http://irreco.garage.maemo.org");
+    QDesktopServices::openUrl(webUrl);
+}
