@@ -3,6 +3,8 @@
 
 #include "licensedlg.h"
 #include <QtGui/QDialog>
+#include <QDesktopServices>
+#include <QUrl>
 
 namespace Ui {
     class AboutDlg;
@@ -22,6 +24,7 @@ private:
 
 private slots:
     //! Opens credits dialog.
+    void on_webButton_clicked();
     void on_creditsButton_clicked();
     //! Shows default GNU license.
     void on_licenseButton_clicked();
