@@ -12,17 +12,15 @@ class BackgroundColorDlg : public QDialog {
     Q_DISABLE_COPY(BackgroundColorDlg)
 public:
     //! Constructor.
-    explicit BackgroundColorDlg(QWidget *parent = 0);
+    explicit BackgroundColorDlg(QWidget *parent = 0, QColor color = 0);
     //! Destructor.
     virtual ~BackgroundColorDlg();
-    //! Integer values of red,green and blue from scrollbars.
-    int r,g,b;
-
-protected:
-    virtual void changeEvent(QEvent *e);
-
-private:
+	
+	
+	private:
     Ui::BackgroundColorDlg *m_ui;
+ 	QString red, green, blue;
+    QPixmap pm;
 
 private slots:
     //! Slot for setting label pixmap.
