@@ -159,16 +159,16 @@ void ButtonSelectDlg::process_line(QString line, int CONF_TYPE)
 {
     switch(CONF_TYPE) {
         case THEME:
-            if(line.contains("name=", Qt::CaseInsensitive) && line.startsWith("n", Qt::CaseInsensitive))
+            if(line.contains(("name="), Qt::CaseInsensitive) && line.startsWith("n", Qt::CaseInsensitive))
                 themeName = line.remove(0,5);
             break;
 
         case BUTTON:
-            if(line.contains("name=", Qt::CaseInsensitive) && line.startsWith("n", Qt::CaseInsensitive))
+            if(line.contains(("name="), Qt::CaseInsensitive) && line.startsWith("n", Qt::CaseInsensitive))
                 buttonName = line.remove(0,5);
-            if(line.contains("up=", Qt::CaseInsensitive) && line.startsWith("u", Qt::CaseInsensitive))
+            if(line.contains(("up="), Qt::CaseInsensitive) && line.startsWith("u", Qt::CaseInsensitive))
                 upButtonName = line.remove(0,3);
-            if(line.contains("down=", Qt::CaseInsensitive) && line.startsWith("d", Qt::CaseInsensitive))
+            if(line.contains(("down="), Qt::CaseInsensitive) && line.startsWith("d", Qt::CaseInsensitive))
                 downButtonName = line.remove(0,5);
             break;
     }
