@@ -20,16 +20,16 @@ class ButtonWidget : public QWidget
 	
 public:
         //! Constructor.
-        explicit ButtonWidget(QWidget *parent, const QString aFileNameUnPressed, QString aFileNamePressed, QString aConfFileName,
-                              QString aButtonText, QStringList commands, int time );
+        explicit ButtonWidget(QWidget *parent, const QString &aFileNameUnPressed, const QString &aFileNamePressed, const QString &aConfFileName,
+                              const QString &aButtonText, const QStringList &commands, int time );
         //! Destructor.
         virtual ~ButtonWidget();
         //! Method for reading button config file.
         void process_line(QString line);
         //! Pressed pixmap to be drawn.
-        QPixmap *pressedPixmap;
+        QPixmap pressedPixmap;
         //! Unpressed pixmap to be drawn.
-        QPixmap *unpressedPixmap;
+        QPixmap unpressedPixmap;
         //! Stringlist which has button commmands.
         QStringList commandChain;
         //! Unpressed file name.
@@ -45,13 +45,13 @@ public:
         //! Font properties, using default font sans-serif if not defined.
         int textUpSize;
         int textUpWeight;
-        QColor *textUpColor;
-        QFont *textUpFont;
+        QColor textUpColor;
+        QFont textUpFont;
 
         int textDownSize;
         int textDownWeight;
         QColor *textDownColor;
-        QFont *textDownFont;
+        QFont textDownFont;
         QString upFontFamily;
         QString downFontFamily;
 
