@@ -6,7 +6,6 @@ CreateBackgroundDlg::CreateBackgroundDlg(QWidget *parent,QVector<ThemeCreatorBac
     m_ui(new Ui::CreateBackgroundDlg)
 {
     m_ui->setupUi(this);
-    //backgrounds = new QVector<ThemeCreatorBackground*>();
     backgrounds = backgroundsVector;
     this->setWindowTitle("Create a background");
     m_ui->addPushButton->setDisabled(true);
@@ -21,9 +20,7 @@ CreateBackgroundDlg::CreateBackgroundDlg(QWidget *parent, ThemeCreatorBackground
     m_ui(new Ui::CreateBackgroundDlg)
 {
     m_ui->setupUi(this);
-    //backgrounds = new QVector<ThemeCreatorBackground*>();
     backgrounds = backgroundsVector;
-   // bg = new ThemeCreatorBackground();
     bg = themeBackground;
     this->setWindowTitle("Create a background");
     m_ui->addPushButton->setEnabled(true);
@@ -45,19 +42,6 @@ void CreateBackgroundDlg::setAddButtonText(QString text)
 {
     m_ui->addPushButton->setText(text);
 }
-
-void CreateBackgroundDlg::changeEvent(QEvent *e)
-{
-    QDialog::changeEvent(e);
-    switch (e->type()) {
-    case QEvent::LanguageChange:
-        m_ui->retranslateUi(this);
-        break;
-    default:
-        break;
-    }
-}
-
 void CreateBackgroundDlg::on_addPushButton_clicked()
 {
     if(!edit && !m_ui->lineEdit->text().isEmpty()) {
@@ -87,7 +71,7 @@ void CreateBackgroundDlg::on_addPushButton_clicked()
 void CreateBackgroundDlg::on_selectPushButton_clicked()
 {
     fileName = QFileDialog::getOpenFileName(this, tr("Open Image"), themesPath, tr("Image Files (*.png)"));
-    QPixmap pix(fileName);
+    if(!fileName.isNull()) { pix.load(fileName); }
     if(!pix.isNull()) {
         if(m_ui->lineEdit->text() != "" )
             m_ui->addPushButton->setEnabled(true);
