@@ -1,8 +1,7 @@
 #ifndef CREATEBACKGROUNDDLG_H
 #define CREATEBACKGROUNDDLG_H
 
-#include <QtGui/QDialog>
-#include <QFileDialog>
+#include <QtGui>
 #include <QMouseEvent>
 #include "themecreatorbackground.h"
 #include <QMessageBox>
@@ -27,7 +26,6 @@ public:
     void setAddButtonText(QString text);
 
 protected:
-    virtual void changeEvent(QEvent *e);
     void mousePressEvent(QMouseEvent *event);
 
 private:
@@ -42,6 +40,8 @@ private:
     ThemeCreatorBackground *bg;
     //! Boolean to tell if editing or adding background.
     bool edit;
+	//! Pixmap for background image.
+    QPixmap pix;
 
 private slots:
     //! Slot for opening file fialog.
