@@ -16,9 +16,6 @@ public:
     //! Destructor.
     virtual ~CreditsDlg();
 
-protected:
-    virtual void changeEvent(QEvent *e);
-
 private:
     Ui::CreditsDlg *m_ui;
 
