@@ -166,8 +166,10 @@ void DownloadRemoteDlg::processReturnValue(int Id,QVariant data)
                 if(line.contains((para),Qt::CaseInsensitive))
                     lircExists = true;
             }
-            if(!lircExists)
+            if(!lircExists) {
                 stream << para + " "+ modelItemString + "\n";
+                system("sudo /etc/init.d/lirc reload");
+            }
 
             lircPathsFile.close();
 
