@@ -326,7 +326,7 @@ void LayoutWidget::addButton(QString fileNameUnPressed, QString fileNamePressed,
      QStringList themeVersionsUsed;
      if(backgroundMode == backgroundFromTheme) {
         QString bgTheme = bgPath;
-        bgTheme = bgTheme.remove(0,26);
+        bgTheme = bgTheme.remove(0,35);
         int slashIndex = bgTheme.indexOf(QChar('/'));
         bgTheme.remove(slashIndex,bgTheme.count()-slashIndex);
         if(!themesUsed.contains((bgTheme),Qt::CaseInsensitive))
@@ -336,8 +336,8 @@ void LayoutWidget::addButton(QString fileNameUnPressed, QString fileNamePressed,
     for( int i=0 ; i<vector->count() ; i++ ) {
         QString themeName;
         QString temp = vector->at(i)->fileNameUnPressed;
-        if(!temp.contains(("/opt/qtirreco/defaulttheme"),Qt::CaseInsensitive)) {
-            temp = temp.remove(0,26);
+        if(!temp.contains(("/opt/qtirreco/themes"),Qt::CaseInsensitive)) {
+            temp = temp.remove(0,35);
             int slashIndex = temp.indexOf(QChar('/'));
             temp.remove(slashIndex,temp.count()-slashIndex);
             themeName = temp;
