@@ -49,6 +49,7 @@ void LoginDbDlg::on_registerPushButton_clicked()
 
 void LoginDbDlg::processReturnValue(int Id,QVariant data)
 {
+    Q_UNUSED(data);
     if (Id == loginId) {
         emit loginReady(m_ui->usernameLineEdit->text(),*hashpwd);
         this->close();
@@ -57,17 +58,18 @@ void LoginDbDlg::processReturnValue(int Id,QVariant data)
 
 void LoginDbDlg::error(int i ,QString string)
 {
-    QMessageBox::warning(this,"Error. ",""+ string,
+    QMessageBox::warning(this,"Error: "+QString::number(i,10), string,
                      QMessageBox::NoButton,QMessageBox::NoButton);
 }
 
 void LoginDbDlg::fault(int i,int j,QString string)
 {
-    QMessageBox::warning(this,"Fault. ",""+ string,
+    Q_UNUSED(j);
+    QMessageBox::warning(this,"Fault: "+QString::number(i,10), string,
                      QMessageBox::NoButton,QMessageBox::NoButton);
 }
 
-void LoginDbDlg::on_okPushButton_2_clicked()
+void LoginDbDlg::on_okPushButton_clicked()
 {
     QByteArray hasharray(QCryptographicHash::hash(m_ui->passwordLineEdit->text().toUtf8(),QCryptographicHash::Sha1));
     hasharray = hasharray.toHex();
