@@ -12,11 +12,14 @@ NewButtonDlg::NewButtonDlg(QWidget *parent, QVector<ButtonWidget*> *vector) :
     editMode = false;
     buttons = vector;
     connect(m_ui->horizontalScrollBar,SIGNAL(valueChanged(int)),this,SLOT(setTimeOut(int)));
-    m_ui->styleChangePushButton->show();
+    connect(m_ui->nameLineEdit,SIGNAL(textChanged(QString)),this,SLOT(allowCreatingButton()));
     m_ui->OkPushButton->setDisabled(true);
     m_ui->horizontalScrollBar->hide();
     m_ui->timeOutLabel->hide();
     m_ui->timeOutValueLabel->hide();
+    this->addPreviewImage(defaultButtonsPath+"blank/unpressed.png",defaultButtonsPath+"blank/pressed.png",
+                          defaultButtonsPath+"blank/button.conf");
+
 }
 
 NewButtonDlg::NewButtonDlg(QWidget *parent, ButtonWidget *child, QVector<ButtonWidget*> *vector) :
@@ -29,6 +32,7 @@ NewButtonDlg::NewButtonDlg(QWidget *parent, ButtonWidget *child, QVector<ButtonW
     buttons = vector;
     button = child;
     connect(m_ui->horizontalScrollBar,SIGNAL(valueChanged(int)),this,SLOT(setTimeOut(int)));
+    connect(m_ui->nameLineEdit,SIGNAL(textChanged(QString)),this,SLOT(allowCreatingButton()));
     m_ui->horizontalScrollBar->hide();
     m_ui->timeOutLabel->hide();
     m_ui->timeOutValueLabel->hide();
@@ -49,19 +53,10 @@ NewButtonDlg::NewButtonDlg(QWidget *parent, ButtonWidget *child, QVector<ButtonW
 
 NewButtonDlg::~NewButtonDlg()
 {
+    delete pix;
     delete m_ui;
 }
 
-void NewButtonDlg::changeEvent(QEvent *e)
-{
-    switch (e->type()) {
-    case QEvent::LanguageChange:
-        m_ui->retranslateUi(this);
-        break;
-    default:
-        break;
-    }
-}
 
 void NewButtonDlg::on_OkPushButton_clicked()
 {
@@ -109,15 +104,13 @@ void NewButtonDlg::on_OkPushButton_clicked()
 
 void NewButtonDlg::on_styleChangePushButton_clicked()
 {
-    ButtonSelectDlg *bsDlg = new ButtonSelectDlg(this);
+    bsDlg = new ButtonSelectDlg(this);
     connect(bsDlg,SIGNAL(signalAddButton(QString, QString, QString)),this,SLOT(addPreviewImage(QString, QString, QString)));
     bsDlg->exec();
-    delete bsDlg;
 }
 
 void NewButtonDlg::addPreviewImage(QString fileNameUnPressed, QString fileNamePressed, QString confFileName)
 {
-    m_ui->styleChangePushButton->hide();
     pix = new QPixmap(fileNameUnPressed);
     m_ui->styleLabel->setPixmap(pix->scaled(128,128,Qt::KeepAspectRatio,Qt::FastTransformation));
     m_ui->styleLabel->setAlignment(Qt::AlignCenter);
@@ -166,10 +159,9 @@ void NewButtonDlg::mousePressEvent(QMouseEvent *event)
 
 void NewButtonDlg::on_addPushButton_clicked()
 {
-    CommandChainDlg *ccDlg = new CommandChainDlg(this);
+    ccDlg = new CommandChainDlg(this);
     connect(ccDlg,SIGNAL(signalAddCommand(QString,QString)),this,SLOT(getCommand(QString,QString)));
     ccDlg->exec();
-    delete ccDlg;
 }
 
 void NewButtonDlg::getCommand(QString commandName,QString modelName)
@@ -226,3 +218,9 @@ void NewButtonDlg::setTimeOut(int timeValue)
     m_ui->timeOutValueLabel->setText(str+"ms");
 
 }
+void NewButtonDlg::allowCreatingButton()
+{
+    if(m_ui->nameLineEdit->text().isEmpty())
+        m_ui->OkPushButton->setDisabled(true);
+    else m_ui->OkPushButton->setEnabled(true);
+}
