@@ -11,6 +11,8 @@
 #include "buttonwidget.h"
 
 class ButtonWidget;
+class ButtonSelectDlg;
+class CommandChainDlg;
 
 namespace Ui {
     class NewButtonDlg;
@@ -28,11 +30,12 @@ public:
     virtual ~NewButtonDlg();
 
 protected:
-    virtual void changeEvent(QEvent *e);
     void mousePressEvent(QMouseEvent *event);
 
 private:
     Ui::NewButtonDlg *m_ui;
+    ButtonSelectDlg *bsDlg;
+    CommandChainDlg *ccDlg;
     //! Method for reading button config.
     void process_line(QString line);
     //! Pixmap for button unpressed.
@@ -61,6 +64,7 @@ private slots:
     //! Emits buttondata to layout.
     void on_OkPushButton_clicked();
     void setTimeOut(int timeValue);
+    void allowCreatingButton();
 
 public slots:
     //! Opens button select dialog.
