@@ -5,6 +5,11 @@ QtIrreco::QtIrreco(QWidget *parent)
     : QMainWindow(parent), m_ui(new Ui::QtIrrecoClass)
 {
     m_ui->setupUi(this);
+
+    // This function makes needed folders and files under /home/user/MyDocs
+    this->createFoldersAndFiles();
+
+
     this->initMenu();
      //Creates empty remotes.conf file
     QFile file(remotesConf);
@@ -55,36 +60,26 @@ QtIrreco::~QtIrreco()
     delete m_ui;
 
 }
-void QtIrreco::changeOldRemoteButtonPaths(QString fileName) // CAN BE DELETED LATER WHEN PROLLY ALL USERS HAVE
-                                                               //   TRIED OLD REMOTES SO THEY ARE FIXED
+void QtIrreco::createFoldersAndFiles()
 {
-    QFile file(remotesPath + fileName);
-    file.open(QIODevice::ReadOnly | QIODevice::Text);
-    QTextStream in(&file);
-    QString data = in.readAll();
-
-    if(data.contains(("/home/user/.qtirreco/themes/default"),Qt::CaseInsensitive))
-        data.replace("/home/user/.qtirreco/themes/default","/home/opt/qtirreco/defaulttheme");
-
-    if(data.contains(("/home/user/MyDocs/qtirreco/.themes"),Qt::CaseInsensitive))
-        data.replace("/home/user/MyDocs/qtirreco/.themes","/home/opt/qtirreco/themes");
-
-    file.remove();
-
-    QFile newFile(remotesPath + fileName);
-    newFile.open(QIODevice::WriteOnly | QIODevice::Text);
-    newFile.write(data.toLatin1(),qstrlen(data.toLatin1()));
-
-    newFile.close();
+    QDir qtirreco;
+    qtirreco.mkdir("/home/user/MyDocs/qtirreco");
+    QDir remotes;
+    remotes.mkdir(remotesPath);
+    QDir devices;
+    devices.mkdir(devicesPath);
+    QDir themes;
+    themes.mkdir(themesPath);
+    QFile lircpaths("/home/user/MyDocs/qtirreco/lircpaths.conf");
+    if (!lircpaths.open(QIODevice::ReadWrite | QIODevice::Text)) {
+        QMessageBox::warning(this,"Error with lircpaths.conf file",
+                             "The program was unable to make lircpaths.conf file",Qt::NoButton,Qt::NoButton);
+        return;
+    }
 }
 
 void QtIrreco::setActiveRemote()
 {
-    // If remote has old paths change them to new.
-    changeOldRemoteButtonPaths(activeRemote+".conf");
-    // Can be deleted later.
-
-
      lw->setActiveRemoteName(activeRemote);
      backgroundName.clear();
      QFile file(remotesPath + activeRemote+".conf");
@@ -96,16 +91,10 @@ void QtIrreco::setActiveRemote()
             this->readRemoteFile(line, in.atEnd());
         }
     file.close();
-
-    // THESE LINES CAN BE DELETED LATER! ! !!! ! ! !
-    this->editRemote();
-    this->saveRemote();
 }
 
 void QtIrreco::checkForRemotes()
 {
-    QDir dir;
-
     QFile file(remotesConf);
 
     if (!file.open(QIODevice::ReadWrite | QIODevice::Text))
@@ -157,14 +146,13 @@ void QtIrreco::noRemotes()
 
 void QtIrreco::newRemote() // Using RenameRemoteDlg class
 {
-    RenameRemoteDlg *rrDlg = new RenameRemoteDlg(this,activeRemote);
-    rrDlg->setWindowTitle("Create a new remote");
-    rrDlg->setNameLabelText("Please enter remote name: ");
-    rrDlg->setPushButtonText("Create remote");
-    rrDlg->setLabelGeometry(260,10,360,31);
-    connect(rrDlg,SIGNAL(newRemote(QString)),this,SLOT(createRemote(QString)));
-    rrDlg->exec();
-    delete rrDlg;
+    newRemo = new RenameRemoteDlg(this,activeRemote);
+    newRemo->setWindowTitle("Create a new remote");
+    newRemo->setNameLabelText("Please enter remote name: ");
+    newRemo->setPushButtonText("Create remote");
+    newRemo->setLabelGeometry(260,10,360,31);
+    connect(newRemo,SIGNAL(newRemote(QString)),this,SLOT(createRemote(QString)));
+    newRemo->exec();
 }
 
 void QtIrreco::createRemote(QString newRemoteName)
@@ -179,7 +167,6 @@ void QtIrreco::createRemote(QString newRemoteName)
         }
     }
     if(!alreadyExists) {
-        QDir dir;
         QFile newRemoteFile(remotesPath + newRemoteName+".conf");
         if (!newRemoteFile.open(QIODevice::ReadWrite | QIODevice::Text))
             return;
@@ -232,11 +219,10 @@ void QtIrreco::editRemote()
 
 void QtIrreco::renameRemote()
 {
-    RenameRemoteDlg *rrDlg = new RenameRemoteDlg(this,activeRemote);
+    rrDlg = new RenameRemoteDlg(this,activeRemote);
     connect(rrDlg,SIGNAL(changeName(QString)),this,SLOT(changeNewRemoteName(QString)));
     rrDlg->setLabelGeometry(230,10,360,31);
     rrDlg->exec();
-    delete rrDlg;
 }
 
 void QtIrreco::changeNewRemoteName(QString newName)
@@ -250,11 +236,11 @@ void QtIrreco::changeNewRemoteName(QString newName)
     if(alreadyExists) {
             QMessageBox::warning(this,"Remote name already exists!","Please choose different remote name.",
                          QMessageBox::NoButton,QMessageBox::NoButton);
-            RenameRemoteDlg *rrDlg = new RenameRemoteDlg(this,activeRemote);
-            connect(rrDlg,SIGNAL(changeName(QString)),this,SLOT(changeNewRemoteName(QString)));
-            rrDlg->setLabelGeometry(230,10,360,31);
-            rrDlg->exec();
-            delete rrDlg;
+            rrDlg2 = new RenameRemoteDlg(this,activeRemote);
+            connect(rrDlg2,SIGNAL(changeName(QString)),this,SLOT(changeNewRemoteName(QString)));
+            rrDlg2->setLabelGeometry(230,10,360,31);
+            rrDlg2->exec();
+
     }
     else {
         oldRemoteName = activeRemote;
@@ -296,13 +282,12 @@ void QtIrreco::writeRemoteChanges() // when renaming remote or changing active r
 
 void QtIrreco::downloadRemote()
 {
-    DownloadRemoteDlg *dloadRmDlg = new DownloadRemoteDlg(this,true,remoteNames);
+    dloadRmDlg = new DownloadRemoteDlg(this,true,remoteNames);
     connect(dloadRmDlg,SIGNAL(lwClearScreen()),lw,SLOT(clearScreen()));
     connect(dloadRmDlg,SIGNAL(addButtonToLayoutSignalFromRSD(QString,QString, QString, QString, QStringList,int)),this,SLOT(addButtonToLayout(QString,QString, QString, QString, QStringList,int)));
     connect(dloadRmDlg,SIGNAL(remoteNameToLayoutWidget(QString)),lw,SLOT(setActiveRemoteName(QString)));
     connect(dloadRmDlg,SIGNAL(remoteNameToLayoutWidget(QString)),this,SLOT(addRemoteName(QString)));
     dloadRmDlg->exec();
-    delete dloadRmDlg;
 }
 
 void QtIrreco::addRemoteName(QString newRemoteName)
@@ -348,10 +333,9 @@ void QtIrreco::addButtonToLayout(QString fileNameUnPressed, QString fileNamePres
 
 void QtIrreco::selectRemote()
 {
-    ChangeRemoteDlg *crDlg = new ChangeRemoteDlg(this, remoteNames);
+    crDlg = new ChangeRemoteDlg(this, remoteNames);
     connect(crDlg,SIGNAL(setActiveRemoteText(QString)),this,SLOT(setActiveRemoteText(QString)));
     crDlg->exec();
-    crDlg->deleteLater();
 }
 
 void QtIrreco::setActiveRemoteText(QString name)
@@ -368,18 +352,17 @@ void QtIrreco::setActiveRemoteText(QString name)
 
 void QtIrreco::deleteRemote() // Using RenameRemoteDlg class
 {
-    RenameRemoteDlg *rrDlg = new RenameRemoteDlg(this,activeRemote);
-    rrDlg->setGeometry(0,0,800,175);
-    rrDlg->setWindowTitle("Delete remote");
-    rrDlg->setNameLabelText("Are you sure you wish to delete remote: "+activeRemote+" ?");
-    rrDlg->setLabelGeometry(150,25,600,50);
-    rrDlg->setPushButtonText("Delete");
-    rrDlg->setPushButtonGeometry(300,85,200,60);
-    rrDlg->enableButton(true);
-    rrDlg->hideLineEdit();
-    connect(rrDlg,SIGNAL(deleteRemote()),this,SLOT(deleteActiveRemote()));
-    rrDlg->exec();
-    delete rrDlg;
+    delDlg = new RenameRemoteDlg(this,activeRemote);
+    delDlg->setGeometry(0,0,800,175);
+    delDlg->setWindowTitle("Delete remote");
+    delDlg->setNameLabelText("Are you sure you wish to delete remote: "+activeRemote+" ?");
+    delDlg->setLabelGeometry(150,25,600,50);
+    delDlg->setPushButtonText("Delete");
+    delDlg->setPushButtonGeometry(300,85,200,60);
+    delDlg->enableButton(true);
+    delDlg->hideLineEdit();
+    connect(delDlg,SIGNAL(deleteRemote()),this,SLOT(deleteActiveRemote()));
+    delDlg->exec();
 }
 
 void QtIrreco::deleteActiveRemote()
@@ -413,24 +396,21 @@ void QtIrreco::deleteActiveRemote()
 
 void QtIrreco::about()
 {
-    AboutDlg *about = new AboutDlg(this);
-    about->exec();
-    delete about;
+    aboutDlg = new AboutDlg(this);
+    aboutDlg->exec();
 }
 
 void QtIrreco::theme()
 {
-    ThemeManager *themeDlg = new ThemeManager(this);
+    themeDlg = new ThemeManager(this);
     themeDlg->exec();
-    delete themeDlg;
 }
 
 void QtIrreco::newButton()
 {
-    NewButtonDlg *newButton = new NewButtonDlg(this, lw->vector);
-    connect(newButton,SIGNAL(addButtonToLayoutSignal(QString,QString, QString, QString, QStringList,int,int)),this,SLOT(addButtonToLayout(QString,QString, QString, QString, QStringList,int,int)));
-    newButton->exec();
-    delete newButton;
+    nbDlg = new NewButtonDlg(this, lw->vector);
+    connect(nbDlg,SIGNAL(addButtonToLayoutSignal(QString,QString, QString, QString, QStringList,int,int)),this,SLOT(addButtonToLayout(QString,QString, QString, QString, QStringList,int,int)));
+    nbDlg->exec();
 }
 
 void QtIrreco::saveRemote()
@@ -467,9 +447,9 @@ void QtIrreco::saveRemote()
         }
     }
 
-
     file.close();
-    QStringList lircFilePaths;
+    QMap<int,QString> lircPaths;
+    lircPaths.clear();
     QFile lircPathsFile(lircpathsConf);
     lircPathsFile.open(QIODevice::ReadOnly | QIODevice::Text);
     QTextStream in(&lircPathsFile);
@@ -481,8 +461,8 @@ void QtIrreco::saveRemote()
                     if(line.at(j).isSpace())
                         line.remove(0,j+1);
                 }
-                if(!lircFilePaths.contains((line),Qt::CaseInsensitive))
-                    lircFilePaths.append(line);
+                    lircPaths.insert(i,line);
+
             }
         }
     }
@@ -495,29 +475,29 @@ void QtIrreco::saveRemote()
     QTextStream out(&remFile);
     out<< "\nLircConfs: ";
     for(int i= 0;i<lircFileNames.length();i++)
-        out<< lircFileNames.at(i) +" ";
+        out<< lircFileNames.at(i) + " ";
+
 
     out<< "\nLircPaths: " ;
 
-    for(int i= 0;i<lircFilePaths.length();i++)
-        out<< lircFilePaths.at(i) +" ";
+    for(int i= 0;i<lircPaths.count();i++)
+          out << lircPaths.value(i) + " ";
+
 
     remFile.close();
 }
 
 void QtIrreco::downloadDB()
 {
-    DownloadUserRemoteDlg *downloadDlg = new DownloadUserRemoteDlg(this);
+    downloadDlg = new DownloadUserRemoteDlg(this);
     connect(downloadDlg,SIGNAL(remoteDownloaded(QString)),this,SLOT(addDownloadedRemote(QString)));
     downloadDlg->exec();
-    delete downloadDlg;
 }
 
 void QtIrreco::uploadDB()
 {
-    UploadDBDlg *uploadDlg = new UploadDBDlg(this, activeRemote);
+    uploadDlg = new UploadDBDlg(this, activeRemote);
     uploadDlg->exec();
-    delete uploadDlg;
 }
 
 void QtIrreco::showRemote()
@@ -841,6 +821,7 @@ void QtIrreco::addDownloadedRemote(QString remName)
 
 void QtIrreco::checkThemesForRemote(QString remoteFile)
 {
+    themesForRemote.clear();
     QString themeTemp;
     QFile file(remotesPath + remoteFile);
     if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
@@ -860,6 +841,7 @@ void QtIrreco::checkThemesForRemote(QString remoteFile)
                     else {
                         themesForRemote.append(themeTemp);
                         themeTemp.clear();
+
                     }
                 }
 
@@ -902,7 +884,6 @@ void QtIrreco::checkThemesForRemote(QString remoteFile)
         m_ui->actionDeleteRemote->setEnabled(true);
         m_ui->actionUploadDb->setEnabled(true);
 
-
     }
     else {
         themeDownloadCount = 0;
@@ -1208,7 +1189,8 @@ void QtIrreco::processReturnValue(int Id,QVariant data)
             QTextStream stream(&lircPathsFile);
             stream << lircConfs.at(callCounter-1) + " "+ lircPathsForRemote.at(callCounter-1) + "\n";
             lircPathsFile.close();
-
+            //Boot lirc here to load added lirc files.
+            system("sudo /etc/init.d/lirc reload");
         }
     }
 }
