@@ -21,7 +21,7 @@
 
 
 
-
+class NewButtonDlg;
 class LayoutWidget;
 
 
@@ -42,6 +42,17 @@ public:
 
 private:
     Ui::QtIrrecoClass *m_ui;
+    RenameRemoteDlg *newRemo;
+    RenameRemoteDlg *rrDlg;
+    RenameRemoteDlg *rrDlg2;
+    DownloadRemoteDlg *dloadRmDlg;
+    ChangeRemoteDlg *crDlg;
+    RenameRemoteDlg *delDlg;
+    AboutDlg *aboutDlg;
+    ThemeManager *themeDlg;
+    NewButtonDlg *nbDlg;
+    DownloadUserRemoteDlg *downloadDlg;
+    UploadDBDlg *uploadDlg;
     //! Renames menu items and hides some actions.
     void initMenu();
     //! Enables edit actions and disables use actions in menu.
@@ -50,8 +61,9 @@ private:
     void enableUseMenu();
     //! Method for checking if any remotes have been created.
     void checkForRemotes();
-    //! If remote has old paths change them to new.           LATER CAN BE DELETED WHEN ALL USERS CHANGED TO NEW VERSION
-    void changeOldRemoteButtonPaths(QString fileName);
+    //! Method for making qtirreco folder and subfolders + lircpaths.conf
+    void createFoldersAndFiles();
+
     //! Few dialog objects.
     RemoteStartupDlg *rsd;
     BackgroundDlg *bg;
