@@ -19,8 +19,6 @@ public:
     //! Destructor.
     virtual ~RegisterDlg();
 
-protected:
-    virtual void changeEvent(QEvent *e);
 
 private:
     Ui::RegisterDlg *m_ui;
