@@ -23,9 +23,6 @@ public:
     //! Destructor.
     virtual ~RemoteStartupDlg();
 
-protected:
-    virtual void changeEvent(QEvent *e);
-
 private:
     Ui::RemoteStartupDlg *m_ui;
   //  QString remote;
@@ -43,10 +40,6 @@ private:
     //! Booleans to help processing lirc file.
     bool flag;
     bool raw_flag;
-    //! Number or added buttons.
-    int addedButtonsCount;
-    //! Number of possible buttons.
-    int buttonsCount;
     //! Contains remote names
     QStringList *remoteNames;
     //! Name for theme to be used creating buttons.
@@ -63,7 +56,7 @@ private:
     ThemeManager *themeDlg;
 
  private slots:
-    //! Emits signal to LayoutWidget to clear screen and make buttons.
+    void on_selectAllButtons_clicked();
     void on_selectThemeButton_clicked();
     void on_pushButton_clicked();
     //! Adds button to selected list.
