@@ -23,9 +23,6 @@ public:
     void hideLineEdit();
     void enableButton(bool enabled);
 
-protected:
-    virtual void changeEvent(QEvent *e);
-
 private:
     Ui::RenameRemoteDlg *m_ui;
 
