@@ -38,30 +38,20 @@ ThemeCreatorDlg::~ThemeCreatorDlg()
     delete backgrounds;
     delete m_ui;
 }
-void ThemeCreatorDlg::changeEvent(QEvent *e)
-{
-    QDialog::changeEvent(e);
-    switch (e->type()) {
-    case QEvent::LanguageChange:
-        m_ui->retranslateUi(this);
-        break;
-    default:
-        break;
-    }
-}
+
 void ThemeCreatorDlg::on_addButton_clicked()
 {
     if(tabIndex == 1) {
-        CreateButtonDlg *createButton = new CreateButtonDlg(this,buttons);
-        connect(createButton,SIGNAL(createButton(QString,QPixmap,QPixmap,QFont,QFont,bool,QString,QString)),this,SLOT(createButton(QString,QPixmap,QPixmap,QFont,QFont,bool,QString,QString )));
-        connect(createButton,SIGNAL(createButton(QString,QPixmap,QPixmap,QFont,QFont,bool,QString,QString)),createButton,SLOT(deleteLater()));
-        createButton->exec();
+        createButtonDlg = new CreateButtonDlg(this,buttons);
+        connect(createButtonDlg,SIGNAL(createButton(QString,QPixmap,QPixmap,QFont,QFont,bool,QString,QString)),this,SLOT(createButton(QString,QPixmap,QPixmap,QFont,QFont,bool,QString,QString )));
+        connect(createButtonDlg,SIGNAL(createButton(QString,QPixmap,QPixmap,QFont,QFont,bool,QString,QString)),createButtonDlg,SLOT(deleteLater()));
+        createButtonDlg->exec();
     }
     if(tabIndex == 2) {
-        CreateBackgroundDlg *createBackground = new CreateBackgroundDlg(this,backgrounds);
-        connect(createBackground,SIGNAL(createBackground(QString,QPixmap,QString)),this,SLOT(createBackground(QString,QPixmap,QString)));
-        connect(createBackground,SIGNAL(createBackground(QString,QPixmap,QString)),createBackground,SLOT(deleteLater()));
-        createBackground->exec();
+        createBackgroundDlg = new CreateBackgroundDlg(this,backgrounds);
+        connect(createBackgroundDlg,SIGNAL(createBackground(QString,QPixmap,QString)),this,SLOT(createBackground(QString,QPixmap,QString)));
+        connect(createBackgroundDlg,SIGNAL(createBackground(QString,QPixmap,QString)),createBackgroundDlg,SLOT(deleteLater()));
+        createBackgroundDlg->exec();
     }
 }
 void ThemeCreatorDlg::createButton(QString buttonName, QPixmap pressedPix,QPixmap unpressedPix,QFont pressedFont,
@@ -89,6 +79,22 @@ void ThemeCreatorDlg::createButton(QString buttonName, QPixmap pressedPix,QPixma
     }
     allowSaving();
 }
+
+void ThemeCreatorDlg::createBackground(QString name, QPixmap background,QString fileName)
+{
+    newBackground = new ThemeCreatorBackground(m_ui->scrollAreaWidgetContents_2);
+    newBackground->setGeometry(0,backgroundHeight,m_ui->scrollAreaWidgetContents_2->width(),160);
+    newBackground->name = name;
+    newBackground->background = background;
+    newBackground->picturePath = fileName;
+    newBackground->createLabels(newBackground->name,newBackground->background);
+    newBackground->show();
+    backgrounds->append(newBackground);
+    backgroundHeight += 170;
+    m_ui->scrollAreaWidgetContents_2->setMinimumHeight(10+backgroundHeight);
+    allowSaving();
+}
+
 void ThemeCreatorDlg::activateTab(int index)
 {
     tabIndex = index;
@@ -178,36 +184,21 @@ void ThemeCreatorDlg::setPreviewPicture(QString picturePath,QString buttonName)
     m_ui->pictureLabel->setPixmap(pix);
     preview_button = buttonName;
 }
-void ThemeCreatorDlg::createBackground(QString name, QPixmap background,QString fileName)
-{
-    newBackground = new ThemeCreatorBackground(m_ui->scrollAreaWidgetContents_2);
-    newBackground->setGeometry(0,backgroundHeight,m_ui->scrollAreaWidgetContents_2->width(),160);
-    newBackground->name = name;
-    newBackground->background = background;
-    newBackground->picturePath = fileName;
-    newBackground->createLabels(newBackground->name,newBackground->background);
-    newBackground->show();
-    backgrounds->append(newBackground);
-    backgroundHeight += 170;
-    m_ui->scrollAreaWidgetContents_2->setMinimumHeight(10+backgroundHeight);
-    allowSaving();
-}
+
 void ThemeCreatorDlg::on_editButton_clicked()
 {
     if(m_ui->tabWidget->currentIndex() == 1) {
-        CreateButtonDlg *cbDlg = new CreateButtonDlg(this,buttons->at(currentButtonIndex),buttons);
+        cbDlg = new CreateButtonDlg(this,buttons->at(currentButtonIndex),buttons);
         cbDlg->setAddButtonText("OK");
         connect(cbDlg,SIGNAL(createButton(QString,QPixmap,QPixmap,QFont,QFont,bool,QString,QString)),
                 this,SLOT(editButton(QString,QPixmap,QPixmap,QFont,QFont,bool,QString,QString)));
         cbDlg->exec();
-        delete cbDlg;
     }
     if(m_ui->tabWidget->currentIndex() == 2) {
-        CreateBackgroundDlg *bgDlg = new CreateBackgroundDlg(this,backgrounds->at(currentBackgroundIndex),backgrounds);
+        bgDlg = new CreateBackgroundDlg(this,backgrounds->at(currentBackgroundIndex),backgrounds);
         bgDlg->setAddButtonText("OK");
         connect(bgDlg,SIGNAL(createBackground(QString,QPixmap,QString)),this,SLOT(editBackground(QString,QPixmap,QString)));
         bgDlg->exec();
-        delete bgDlg;
     }
 }
 void ThemeCreatorDlg::editButton(QString buttonName, QPixmap pressedPix,QPixmap unpressedPix,QFont pressedFont,QFont unpressedFont,
