@@ -28,11 +28,14 @@ public:
     int num;
 
 protected:
-    virtual void changeEvent(QEvent *e);
     void mousePressEvent(QMouseEvent *event);
 
 private:
     Ui::ThemeCreatorDlg *m_ui;
+    CreateButtonDlg *createButtonDlg;
+    CreateBackgroundDlg *createBackgroundDlg;
+    CreateButtonDlg *cbDlg;
+    CreateBackgroundDlg *bgDlg;
     //! Variable for current tab index.
     int tabIndex;
     //! Vector which holds themes buttons.
