@@ -30,8 +30,8 @@ ThemeManager::ThemeManager(QWidget *parent) :
     connect(client,SIGNAL(finish(int,QVariant)),this,SLOT(processReturnValue(int,QVariant)));
     connect(client,SIGNAL(networkError(int,QString)),this,SLOT(error(int,QString)));
     connect(client,SIGNAL(fault(int,int,QString)),this,SLOT(fault(int,int,QString)));
-    connect(m_ui->versionComboBox,SIGNAL(activated(int)),this,SLOT(themeVersionChanged(int)));
-    connect(m_ui->versionComboBox,SIGNAL(activated(QString)),this,SLOT(themeVersionChanged(QString)));
+    connect(m_ui->versionComboBox,SIGNAL(activated(int)),this,SLOT(themeVersionRowChanged(int)));
+    connect(m_ui->versionComboBox,SIGNAL(activated(QString)),this,SLOT(themeVersionStringChanged(QString)));
     connect(m_ui->previousPushButton,SIGNAL(clicked()),this,SLOT(clearAllData()));
 
     themeNameIndex = 0;
@@ -55,22 +55,12 @@ ThemeManager::~ThemeManager()
     delete m_ui;
 }
 
-void ThemeManager::changeEvent(QEvent *e)
-{
-    QDialog::changeEvent(e);
-    switch (e->type()) {
-    case QEvent::LanguageChange:
-        m_ui->retranslateUi(this);
-        break;
-    default:
-        break;
-    }
-}
-void ThemeManager::themeVersionChanged(int clickedRow)
+void ThemeManager::themeVersionRowChanged(int clickedRow)
 {
     currentVersionRow = clickedRow;
 }
-void ThemeManager::themeVersionChanged(QString version)
+
+void ThemeManager::themeVersionStringChanged(QString version)
 {
     int versionId = themeVersions.value(version);
     QList<QVariant> params;
@@ -83,10 +73,9 @@ void ThemeManager::themeVersionChanged(QString version)
 }
 void ThemeManager::on_newPushButton_clicked()
 {
-    ThemeCreatorDlg *themeCreatorDlg = new ThemeCreatorDlg(this);
+    themeCreatorDlg = new ThemeCreatorDlg(this);
     connect(themeCreatorDlg,SIGNAL(themeCreated()),this,SLOT(clearAllData()));
     themeCreatorDlg->exec();
-    delete themeCreatorDlg;
 }
 void ThemeManager::updateListWidget(QListWidgetItem *item)
 {
@@ -666,10 +655,9 @@ void ThemeManager::on_downloadPushButton_clicked()
         uploadButtonIndex = 0;
         uploadBgIndex = 0;
         // First login to DB
-        LoginDbDlg *loginDlg = new LoginDbDlg(this);
+        loginDlg = new LoginDbDlg(this);
         connect(loginDlg,SIGNAL(loginReady(QString,QString)),this,SLOT(startUpload(QString,QString)));
         loginDlg->exec();
-        delete loginDlg;
     }
 }
 QString ThemeManager::readVersion(QString line)
@@ -772,7 +760,7 @@ void ThemeManager::loadThemes()
 
     for(int i=0;i<deviceThemeCount;i++)
     {
-        QListWidgetItem *item = new QListWidgetItem();
+
 
         QString themeConf = themesPath + strList.at(i) + "/theme.conf";
         QFile file(themeConf);
@@ -792,9 +780,9 @@ void ThemeManager::loadThemes()
                 process_line(line);
             }
 
-            item->setText(themeName);
-
-            m_ui->listWidget->insertItem(i, item);
+          //  item->setText(themeName);
+new QListWidgetItem(themeName,m_ui->listWidget);
+            //m_ui->listWidget->insertItem(i, item);
             m_ui->listWidget->show();
             file.close();
         }
@@ -803,14 +791,8 @@ void ThemeManager::loadThemes()
 void ThemeManager::process_line(QString line)
 {
         if(line.contains(("name="), Qt::CaseInsensitive))
-        {
-            QString x = line;
-            int count;
-            int chars;
-            count = line.length();
-            chars = count - 5;
-            themeName = x.right(chars);
-        }
+            themeName = line.right(line.length() - 5);
+
 }
 void ThemeManager::readThemeConf(QString line)
 {
@@ -939,7 +921,7 @@ void ThemeManager::on_deletePushButton_clicked()
 
     if(!themeUsedInRemote) {
 
-        QDialog *del = new QDialog(this);
+        del = new QDialog(this);
         del->setWindowTitle("Delete theme");
         del->resize(800,150);
         QLabel *label = new QLabel(del);
@@ -1012,7 +994,7 @@ void ThemeManager::deleteTheme(QString delThemeName)
         file.remove();
     }
     dir.setPath(homePath);
-    QString delCommand("rm -rf /home/opt/qtirreco/themes/" + delThemeName);
+    QString delCommand("rm -rf "+ themesPath + delThemeName);
     system(delCommand.toAscii().data());
 }
 void ThemeManager::deleteTheme()
@@ -1051,7 +1033,7 @@ void ThemeManager::deleteTheme()
         file.remove();
     }
     dir.setPath(homePath);
-    QString delCommand("rm -rf /home/opt/qtirreco/themes/" + themeToDelete);
+    QString delCommand("rm -rf "+ themesPath + themeToDelete);
     system(delCommand.toAscii().data());
     QDir themeDir(themesPath + themeToDelete);
     if(!themeDir.exists())
@@ -1114,7 +1096,7 @@ void ThemeManager::replaceTheme()
         file.remove();
     }
     dir.setPath(homePath);
-    QString delCommand("rm -rf /home/opt/qtirreco/themes/" + themeToDelete);
+    QString delCommand("rm -rf "+ themesPath + themeToDelete);
     system(delCommand.toAscii().data());
 
     QDir themeDir(themesPath + themeToDelete);
